# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from smart_diagnostics_client.api_client import ApiClient


class IndicatorsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_burst_data_audio(self, indicator_id, utc_timestamp, **kwargs):  # noqa: E501
        """Generates audio from Indicator burst data.  Only vibration Indicators are supported.  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_burst_data_audio(indicator_id, utc_timestamp, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str indicator_id: The indicator to generate audio for (required)
        :param int utc_timestamp: The UTC timestamp used to locate the burst data used to generate the audio (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_burst_data_audio_with_http_info(indicator_id, utc_timestamp, **kwargs)  # noqa: E501
        else:
            (data) = self.get_burst_data_audio_with_http_info(indicator_id, utc_timestamp, **kwargs)  # noqa: E501
            return data

    def get_burst_data_audio_with_http_info(self, indicator_id, utc_timestamp, **kwargs):  # noqa: E501
        """Generates audio from Indicator burst data.  Only vibration Indicators are supported.  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_burst_data_audio_with_http_info(indicator_id, utc_timestamp, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str indicator_id: The indicator to generate audio for (required)
        :param int utc_timestamp: The UTC timestamp used to locate the burst data used to generate the audio (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['indicator_id', 'utc_timestamp']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_burst_data_audio" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'indicator_id' is set
        if ('indicator_id' not in params or
                params['indicator_id'] is None):
            raise ValueError("Missing the required parameter `indicator_id` when calling `get_burst_data_audio`")  # noqa: E501
        # verify the required parameter 'utc_timestamp' is set
        if ('utc_timestamp' not in params or
                params['utc_timestamp'] is None):
            raise ValueError("Missing the required parameter `utc_timestamp` when calling `get_burst_data_audio`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'indicator_id' in params:
            path_params['indicatorId'] = params['indicator_id']  # noqa: E501
        if 'utc_timestamp' in params:
            path_params['utcTimestamp'] = params['utc_timestamp']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Indicators/{indicatorId}/burstDataAudio/{utcTimestamp}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_indicator(self, indicator_id, **kwargs):  # noqa: E501
        """Gets an indicator response  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_indicator(indicator_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str indicator_id: (required)
        :return: IndicatorResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_indicator_with_http_info(indicator_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_indicator_with_http_info(indicator_id, **kwargs)  # noqa: E501
            return data

    def get_indicator_with_http_info(self, indicator_id, **kwargs):  # noqa: E501
        """Gets an indicator response  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_indicator_with_http_info(indicator_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str indicator_id: (required)
        :return: IndicatorResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['indicator_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_indicator" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'indicator_id' is set
        if ('indicator_id' not in params or
                params['indicator_id'] is None):
            raise ValueError("Missing the required parameter `indicator_id` when calling `get_indicator`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'indicator_id' in params:
            path_params['indicatorId'] = params['indicator_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Indicators/{indicatorId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='IndicatorResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_indicator_alarm_state(self, indicator_id, **kwargs):  # noqa: E501
        """Get the alarm state for a specific indicator  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_indicator_alarm_state(indicator_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str indicator_id: Id of specific indicator (required)
        :return: IndicatorAlarmStateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_indicator_alarm_state_with_http_info(indicator_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_indicator_alarm_state_with_http_info(indicator_id, **kwargs)  # noqa: E501
            return data

    def get_indicator_alarm_state_with_http_info(self, indicator_id, **kwargs):  # noqa: E501
        """Get the alarm state for a specific indicator  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_indicator_alarm_state_with_http_info(indicator_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str indicator_id: Id of specific indicator (required)
        :return: IndicatorAlarmStateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['indicator_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_indicator_alarm_state" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'indicator_id' is set
        if ('indicator_id' not in params or
                params['indicator_id'] is None):
            raise ValueError("Missing the required parameter `indicator_id` when calling `get_indicator_alarm_state`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'indicator_id' in params:
            path_params['indicatorId'] = params['indicator_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Indicators/{indicatorId}/alarmState', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='IndicatorAlarmStateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_indicator_statistics(self, **kwargs):  # noqa: E501
        """Gets indicator statistics  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_indicator_statistics(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] group_ids: A list of groupIds to filter the result
        :param list[str] filter_ids: A list of filterIds to filter the result
        :param datetime start_date: Start of the time duration used to calculate the statistics. Defaults to one day.
        :param datetime end_date: End of the time duration used to calculate the statistics. Defaults to one day.
        :param bool is_export: If true, this route will email an excel workbook instead of returning the json response
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Id` | Guid | `eq, neq, in` | | `IndicatorType` | MetricTypeCodes | `eq, neq, in` | | `MeasureOf` | SensorRoleTypeCodes | `eq, neq, in` | | `Name` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `AverageValue` | Double? | | `MaxValue` | Double? | | `MeasureOf` | SensorRoleTypeCodes | | `OnTime` | Double? | | `SystemSortOrder` | Int32 | | `TimeInAlarm` | Double? | | `TimeInWarning` | Double? |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `HierarchyAbbreviation`, `HierarchyName`.
        :return: PagedResultsModelIndicatorStatisticsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_indicator_statistics_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_indicator_statistics_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_indicator_statistics_with_http_info(self, **kwargs):  # noqa: E501
        """Gets indicator statistics  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_indicator_statistics_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] group_ids: A list of groupIds to filter the result
        :param list[str] filter_ids: A list of filterIds to filter the result
        :param datetime start_date: Start of the time duration used to calculate the statistics. Defaults to one day.
        :param datetime end_date: End of the time duration used to calculate the statistics. Defaults to one day.
        :param bool is_export: If true, this route will email an excel workbook instead of returning the json response
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Id` | Guid | `eq, neq, in` | | `IndicatorType` | MetricTypeCodes | `eq, neq, in` | | `MeasureOf` | SensorRoleTypeCodes | `eq, neq, in` | | `Name` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `AverageValue` | Double? | | `MaxValue` | Double? | | `MeasureOf` | SensorRoleTypeCodes | | `OnTime` | Double? | | `SystemSortOrder` | Int32 | | `TimeInAlarm` | Double? | | `TimeInWarning` | Double? |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `HierarchyAbbreviation`, `HierarchyName`.
        :return: PagedResultsModelIndicatorStatisticsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_ids', 'filter_ids', 'start_date', 'end_date', 'is_export', 'filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_indicator_statistics" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'group_ids' in params:
            query_params.append(('groupIds', params['group_ids']))  # noqa: E501
            collection_formats['groupIds'] = 'multi'  # noqa: E501
        if 'filter_ids' in params:
            query_params.append(('filterIds', params['filter_ids']))  # noqa: E501
            collection_formats['filterIds'] = 'multi'  # noqa: E501
        if 'start_date' in params:
            query_params.append(('startDate', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('endDate', params['end_date']))  # noqa: E501
        if 'is_export' in params:
            query_params.append(('isExport', params['is_export']))  # noqa: E501
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Indicators/statistics', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelIndicatorStatisticsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_indicator_types(self, **kwargs):  # noqa: E501
        """Gets indicator types  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_indicator_types(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Name` | String | `eq, neq, like, in` | | `Name` | String | `eq, neq, like, in` |
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Id` | Int32 | | `IndicatorType` | MetricTypeCodes | | `Name` | String |
        :return: list[IndicatorTypesResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_indicator_types_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_indicator_types_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_indicator_types_with_http_info(self, **kwargs):  # noqa: E501
        """Gets indicator types  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_indicator_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Name` | String | `eq, neq, like, in` | | `Name` | String | `eq, neq, like, in` |
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Id` | Int32 | | `IndicatorType` | MetricTypeCodes | | `Name` | String |
        :return: list[IndicatorTypesResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'order_by']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_indicator_types" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Indicators/Types', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[IndicatorTypesResponse]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_indicators(self, **kwargs):  # noqa: E501
        """Gets indicator responses  # noqa: E501

        NOTE: 'OR' filtering is not supported by this endpoint.  Required Permissions: Location User.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_indicators(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] group_ids: A list of groupIds to filter the result
        :param list[str] filter_ids: A list of filterIds to filter the result
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Classification` | MetricClassificationSourceEnum | `eq, neq, in` | | `ClassificationIndicatorSourceId` | Guid? | `eq, neq, in, lt, gt, leq, geq` | | `CorporationId` | Guid | `eq, neq, in` | | `Id` | Guid | `eq, neq, in` | | `IndicatorType` | MetricTypeCodes | `eq, neq, in` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `MeasureOf` | SensorRoleTypeCodes | `eq, neq, in` | | `Name` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `CorporationId` | Guid | | `Id` | Guid | | `MeasureOf` | SensorRoleTypeCodes | | `Name` | String | | `SystemSortOrder` | Int32 |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `HierarchySearch`, `Name`.
        :return: PagedResultsModelIndicatorResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_indicators_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_indicators_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_indicators_with_http_info(self, **kwargs):  # noqa: E501
        """Gets indicator responses  # noqa: E501

        NOTE: 'OR' filtering is not supported by this endpoint.  Required Permissions: Location User.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_indicators_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] group_ids: A list of groupIds to filter the result
        :param list[str] filter_ids: A list of filterIds to filter the result
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Classification` | MetricClassificationSourceEnum | `eq, neq, in` | | `ClassificationIndicatorSourceId` | Guid? | `eq, neq, in, lt, gt, leq, geq` | | `CorporationId` | Guid | `eq, neq, in` | | `Id` | Guid | `eq, neq, in` | | `IndicatorType` | MetricTypeCodes | `eq, neq, in` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `MeasureOf` | SensorRoleTypeCodes | `eq, neq, in` | | `Name` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `CorporationId` | Guid | | `Id` | Guid | | `MeasureOf` | SensorRoleTypeCodes | | `Name` | String | | `SystemSortOrder` | Int32 |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `HierarchySearch`, `Name`.
        :return: PagedResultsModelIndicatorResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_ids', 'filter_ids', 'filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_indicators" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'group_ids' in params:
            query_params.append(('groupIds', params['group_ids']))  # noqa: E501
            collection_formats['groupIds'] = 'multi'  # noqa: E501
        if 'filter_ids' in params:
            query_params.append(('filterIds', params['filter_ids']))  # noqa: E501
            collection_formats['filterIds'] = 'multi'  # noqa: E501
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Indicators', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelIndicatorResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_indicators_alarm_state(self, **kwargs):  # noqa: E501
        """Get the alarm state for a list of indicators  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_indicators_alarm_state(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Id` | Guid | `eq, neq, in` |
        :return: list[IndicatorAlarmStateResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_indicators_alarm_state_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_indicators_alarm_state_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_indicators_alarm_state_with_http_info(self, **kwargs):  # noqa: E501
        """Get the alarm state for a list of indicators  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_indicators_alarm_state_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Id` | Guid | `eq, neq, in` |
        :return: list[IndicatorAlarmStateResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_indicators_alarm_state" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Indicators/alarmState', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[IndicatorAlarmStateResponse]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_measure_ofs_for_indicator(self, **kwargs):  # noqa: E501
        """Returns a list of measureOf values and their UI-friendly format  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_measure_ofs_for_indicator(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: IndicatorOptionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_measure_ofs_for_indicator_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_measure_ofs_for_indicator_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_measure_ofs_for_indicator_with_http_info(self, **kwargs):  # noqa: E501
        """Returns a list of measureOf values and their UI-friendly format  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_measure_ofs_for_indicator_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: IndicatorOptionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_measure_ofs_for_indicator" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Indicators/measureOfs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='IndicatorOptionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_options_for_indicator(self, **kwargs):  # noqa: E501
        """Gets options for indicators  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_options_for_indicator(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: IndicatorOptionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_options_for_indicator_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_options_for_indicator_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_options_for_indicator_with_http_info(self, **kwargs):  # noqa: E501
        """Gets options for indicators  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_options_for_indicator_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: IndicatorOptionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_options_for_indicator" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Indicators/options', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='IndicatorOptionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_statistics_for_indicator(self, indicator_id, **kwargs):  # noqa: E501
        """Gets statistics for a specific indicator  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_statistics_for_indicator(indicator_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str indicator_id: Id of requested indicator (required)
        :param datetime start_date: Start of the time duration used to calculate the statistics. Defaults to one day.
        :param datetime end_date: End of the time duration used to calculate the statistics. Defaults to one day.
        :return: IndicatorStatisticsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_statistics_for_indicator_with_http_info(indicator_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_statistics_for_indicator_with_http_info(indicator_id, **kwargs)  # noqa: E501
            return data

    def get_statistics_for_indicator_with_http_info(self, indicator_id, **kwargs):  # noqa: E501
        """Gets statistics for a specific indicator  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_statistics_for_indicator_with_http_info(indicator_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str indicator_id: Id of requested indicator (required)
        :param datetime start_date: Start of the time duration used to calculate the statistics. Defaults to one day.
        :param datetime end_date: End of the time duration used to calculate the statistics. Defaults to one day.
        :return: IndicatorStatisticsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['indicator_id', 'start_date', 'end_date']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_statistics_for_indicator" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'indicator_id' is set
        if ('indicator_id' not in params or
                params['indicator_id'] is None):
            raise ValueError("Missing the required parameter `indicator_id` when calling `get_statistics_for_indicator`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'indicator_id' in params:
            path_params['indicatorId'] = params['indicator_id']  # noqa: E501

        query_params = []
        if 'start_date' in params:
            query_params.append(('startDate', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('endDate', params['end_date']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Indicators/{indicatorId}/statistics', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='IndicatorStatisticsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_smart_alarms(self, indicator_id, **kwargs):  # noqa: E501
        """Calculates and sets smart alarms for the given indicator.  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_smart_alarms(indicator_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str indicator_id: The indicator to calculate the thresholds for (required)
        :param SmartAlarmsRequest body:
        :return: IndicatorResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_smart_alarms_with_http_info(indicator_id, **kwargs)  # noqa: E501
        else:
            (data) = self.set_smart_alarms_with_http_info(indicator_id, **kwargs)  # noqa: E501
            return data

    def set_smart_alarms_with_http_info(self, indicator_id, **kwargs):  # noqa: E501
        """Calculates and sets smart alarms for the given indicator.  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_smart_alarms_with_http_info(indicator_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str indicator_id: The indicator to calculate the thresholds for (required)
        :param SmartAlarmsRequest body:
        :return: IndicatorResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['indicator_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_smart_alarms" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'indicator_id' is set
        if ('indicator_id' not in params or
                params['indicator_id'] is None):
            raise ValueError("Missing the required parameter `indicator_id` when calling `set_smart_alarms`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'indicator_id' in params:
            path_params['indicatorId'] = params['indicator_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Indicators/{indicatorId}/smartAlarms', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='IndicatorResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from smart_diagnostics_client.api_client import ApiClient


class HardwareEventsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_hardware_events_for_location(self, location_id, **kwargs):  # noqa: E501
        """Gets a listing of hardware event logs for a location.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_hardware_events_for_location(location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str location_id: (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `EventType` | String | `eq, neq, like, in` | | `HardwareType` | String | `eq, neq, like, in` | | `TimeAcked` | DateTime? | `eq, neq, in, lt, gt, leq, geq` | | `TimeEntered` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `TimeExited` | DateTime? | `eq, neq, in, lt, gt, leq, geq` | | `TimeNotified` | DateTime | `eq, neq, in, lt, gt, leq, geq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `EventType` | String | | `HardwareType` | String | | `TimeAcked` | DateTime? | | `TimeEntered` | DateTime | | `TimeExited` | DateTime? | | `TimeNotified` | DateTime |
        :return: PagedResultsModelHardwareEventModelV3
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_hardware_events_for_location_with_http_info(location_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_hardware_events_for_location_with_http_info(location_id, **kwargs)  # noqa: E501
            return data

    def get_hardware_events_for_location_with_http_info(self, location_id, **kwargs):  # noqa: E501
        """Gets a listing of hardware event logs for a location.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_hardware_events_for_location_with_http_info(location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str location_id: (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `EventType` | String | `eq, neq, like, in` | | `HardwareType` | String | `eq, neq, like, in` | | `TimeAcked` | DateTime? | `eq, neq, in, lt, gt, leq, geq` | | `TimeEntered` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `TimeExited` | DateTime? | `eq, neq, in, lt, gt, leq, geq` | | `TimeNotified` | DateTime | `eq, neq, in, lt, gt, leq, geq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `EventType` | String | | `HardwareType` | String | | `TimeAcked` | DateTime? | | `TimeEntered` | DateTime | | `TimeExited` | DateTime? | | `TimeNotified` | DateTime |
        :return: PagedResultsModelHardwareEventModelV3
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['location_id', 'filter', 'page', 'page_limit', 'order_by']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_hardware_events_for_location" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'location_id' is set
        if ('location_id' not in params or
                params['location_id'] is None):
            raise ValueError("Missing the required parameter `location_id` when calling `get_hardware_events_for_location`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'location_id' in params:
            path_params['locationId'] = params['location_id']  # noqa: E501

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/HardwareEvents/location/{locationId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelHardwareEventModelV3',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NodeResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'location': 'LocationChild',
        'corporation': 'CorporationChild',
        'hub': 'HubChild',
        'base_station': 'BaseStationNodeChild',
        'repeater': 'RepeaterNodeChild',
        'serial_number': 'str',
        'nickname': 'str',
        'firmware_version': 'str',
        'node_type_code': 'NodeTypeCodes',
        'active': 'bool',
        'created': 'datetime',
        'updated': 'datetime',
        'monitoring_points': 'list[MonitoringPointChild]',
        'battery_voltage': 'float',
        'burst_success_rate': 'float',
        'is_online': 'bool',
        'last_update_time': 'datetime',
        'packet_success_rate': 'float',
        'temperature': 'float',
        'wireless_efficiency': 'float'
    }

    attribute_map = {
        'id': 'Id',
        'location': 'Location',
        'corporation': 'Corporation',
        'hub': 'Hub',
        'base_station': 'BaseStation',
        'repeater': 'Repeater',
        'serial_number': 'SerialNumber',
        'nickname': 'Nickname',
        'firmware_version': 'FirmwareVersion',
        'node_type_code': 'NodeTypeCode',
        'active': 'Active',
        'created': 'Created',
        'updated': 'Updated',
        'monitoring_points': 'MonitoringPoints',
        'battery_voltage': 'BatteryVoltage',
        'burst_success_rate': 'BurstSuccessRate',
        'is_online': 'IsOnline',
        'last_update_time': 'LastUpdateTime',
        'packet_success_rate': 'PacketSuccessRate',
        'temperature': 'Temperature',
        'wireless_efficiency': 'WirelessEfficiency'
    }

    def __init__(self, id=None, location=None, corporation=None, hub=None, base_station=None, repeater=None, serial_number=None, nickname=None, firmware_version=None, node_type_code=None, active=None, created=None, updated=None, monitoring_points=None, battery_voltage=None, burst_success_rate=None, is_online=None, last_update_time=None, packet_success_rate=None, temperature=None, wireless_efficiency=None):  # noqa: E501
        """NodeResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._location = None
        self._corporation = None
        self._hub = None
        self._base_station = None
        self._repeater = None
        self._serial_number = None
        self._nickname = None
        self._firmware_version = None
        self._node_type_code = None
        self._active = None
        self._created = None
        self._updated = None
        self._monitoring_points = None
        self._battery_voltage = None
        self._burst_success_rate = None
        self._is_online = None
        self._last_update_time = None
        self._packet_success_rate = None
        self._temperature = None
        self._wireless_efficiency = None
        self.discriminator = None
        self.id = id
        self.location = location
        self.corporation = corporation
        if hub is not None:
            self.hub = hub
        if base_station is not None:
            self.base_station = base_station
        if repeater is not None:
            self.repeater = repeater
        self.serial_number = serial_number
        if nickname is not None:
            self.nickname = nickname
        if firmware_version is not None:
            self.firmware_version = firmware_version
        self.node_type_code = node_type_code
        self.active = active
        self.created = created
        self.updated = updated
        self.monitoring_points = monitoring_points
        if battery_voltage is not None:
            self.battery_voltage = battery_voltage
        if burst_success_rate is not None:
            self.burst_success_rate = burst_success_rate
        if is_online is not None:
            self.is_online = is_online
        if last_update_time is not None:
            self.last_update_time = last_update_time
        if packet_success_rate is not None:
            self.packet_success_rate = packet_success_rate
        if temperature is not None:
            self.temperature = temperature
        if wireless_efficiency is not None:
            self.wireless_efficiency = wireless_efficiency

    @property
    def id(self):
        """Gets the id of this NodeResponse.  # noqa: E501

        The id of the node  # noqa: E501

        :return: The id of this NodeResponse.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this NodeResponse.

        The id of the node  # noqa: E501

        :param id: The id of this NodeResponse.  # noqa: E501
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def location(self):
        """Gets the location of this NodeResponse.  # noqa: E501


        :return: The location of this NodeResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this NodeResponse.


        :param location: The location of this NodeResponse.  # noqa: E501
        :type: LocationChild
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    @property
    def corporation(self):
        """Gets the corporation of this NodeResponse.  # noqa: E501


        :return: The corporation of this NodeResponse.  # noqa: E501
        :rtype: CorporationChild
        """
        return self._corporation

    @corporation.setter
    def corporation(self, corporation):
        """Sets the corporation of this NodeResponse.


        :param corporation: The corporation of this NodeResponse.  # noqa: E501
        :type: CorporationChild
        """
        if corporation is None:
            raise ValueError("Invalid value for `corporation`, must not be `None`")  # noqa: E501

        self._corporation = corporation

    @property
    def hub(self):
        """Gets the hub of this NodeResponse.  # noqa: E501


        :return: The hub of this NodeResponse.  # noqa: E501
        :rtype: HubChild
        """
        return self._hub

    @hub.setter
    def hub(self, hub):
        """Sets the hub of this NodeResponse.


        :param hub: The hub of this NodeResponse.  # noqa: E501
        :type: HubChild
        """

        self._hub = hub

    @property
    def base_station(self):
        """Gets the base_station of this NodeResponse.  # noqa: E501


        :return: The base_station of this NodeResponse.  # noqa: E501
        :rtype: BaseStationNodeChild
        """
        return self._base_station

    @base_station.setter
    def base_station(self, base_station):
        """Sets the base_station of this NodeResponse.


        :param base_station: The base_station of this NodeResponse.  # noqa: E501
        :type: BaseStationNodeChild
        """

        self._base_station = base_station

    @property
    def repeater(self):
        """Gets the repeater of this NodeResponse.  # noqa: E501


        :return: The repeater of this NodeResponse.  # noqa: E501
        :rtype: RepeaterNodeChild
        """
        return self._repeater

    @repeater.setter
    def repeater(self, repeater):
        """Sets the repeater of this NodeResponse.


        :param repeater: The repeater of this NodeResponse.  # noqa: E501
        :type: RepeaterNodeChild
        """

        self._repeater = repeater

    @property
    def serial_number(self):
        """Gets the serial_number of this NodeResponse.  # noqa: E501

        The serial number of the node  # noqa: E501

        :return: The serial_number of this NodeResponse.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this NodeResponse.

        The serial number of the node  # noqa: E501

        :param serial_number: The serial_number of this NodeResponse.  # noqa: E501
        :type: str
        """
        if serial_number is None:
            raise ValueError("Invalid value for `serial_number`, must not be `None`")  # noqa: E501

        self._serial_number = serial_number

    @property
    def nickname(self):
        """Gets the nickname of this NodeResponse.  # noqa: E501

        The name of the node  # noqa: E501

        :return: The nickname of this NodeResponse.  # noqa: E501
        :rtype: str
        """
        return self._nickname

    @nickname.setter
    def nickname(self, nickname):
        """Sets the nickname of this NodeResponse.

        The name of the node  # noqa: E501

        :param nickname: The nickname of this NodeResponse.  # noqa: E501
        :type: str
        """

        self._nickname = nickname

    @property
    def firmware_version(self):
        """Gets the firmware_version of this NodeResponse.  # noqa: E501

        The firmware version of the node  # noqa: E501

        :return: The firmware_version of this NodeResponse.  # noqa: E501
        :rtype: str
        """
        return self._firmware_version

    @firmware_version.setter
    def firmware_version(self, firmware_version):
        """Sets the firmware_version of this NodeResponse.

        The firmware version of the node  # noqa: E501

        :param firmware_version: The firmware_version of this NodeResponse.  # noqa: E501
        :type: str
        """

        self._firmware_version = firmware_version

    @property
    def node_type_code(self):
        """Gets the node_type_code of this NodeResponse.  # noqa: E501


        :return: The node_type_code of this NodeResponse.  # noqa: E501
        :rtype: NodeTypeCodes
        """
        return self._node_type_code

    @node_type_code.setter
    def node_type_code(self, node_type_code):
        """Sets the node_type_code of this NodeResponse.


        :param node_type_code: The node_type_code of this NodeResponse.  # noqa: E501
        :type: NodeTypeCodes
        """
        if node_type_code is None:
            raise ValueError("Invalid value for `node_type_code`, must not be `None`")  # noqa: E501

        self._node_type_code = node_type_code

    @property
    def active(self):
        """Gets the active of this NodeResponse.  # noqa: E501

        Boolean set to true if the node is active  # noqa: E501

        :return: The active of this NodeResponse.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this NodeResponse.

        Boolean set to true if the node is active  # noqa: E501

        :param active: The active of this NodeResponse.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def created(self):
        """Gets the created of this NodeResponse.  # noqa: E501

        The date the node is created  # noqa: E501

        :return: The created of this NodeResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this NodeResponse.

        The date the node is created  # noqa: E501

        :param created: The created of this NodeResponse.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this NodeResponse.  # noqa: E501

        The date the node is last updated  # noqa: E501

        :return: The updated of this NodeResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this NodeResponse.

        The date the node is last updated  # noqa: E501

        :param updated: The updated of this NodeResponse.  # noqa: E501
        :type: datetime
        """
        if updated is None:
            raise ValueError("Invalid value for `updated`, must not be `None`")  # noqa: E501

        self._updated = updated

    @property
    def monitoring_points(self):
        """Gets the monitoring_points of this NodeResponse.  # noqa: E501

        The monitoring points associated with the node  # noqa: E501

        :return: The monitoring_points of this NodeResponse.  # noqa: E501
        :rtype: list[MonitoringPointChild]
        """
        return self._monitoring_points

    @monitoring_points.setter
    def monitoring_points(self, monitoring_points):
        """Sets the monitoring_points of this NodeResponse.

        The monitoring points associated with the node  # noqa: E501

        :param monitoring_points: The monitoring_points of this NodeResponse.  # noqa: E501
        :type: list[MonitoringPointChild]
        """
        if monitoring_points is None:
            raise ValueError("Invalid value for `monitoring_points`, must not be `None`")  # noqa: E501

        self._monitoring_points = monitoring_points

    @property
    def battery_voltage(self):
        """Gets the battery_voltage of this NodeResponse.  # noqa: E501


        :return: The battery_voltage of this NodeResponse.  # noqa: E501
        :rtype: float
        """
        return self._battery_voltage

    @battery_voltage.setter
    def battery_voltage(self, battery_voltage):
        """Sets the battery_voltage of this NodeResponse.


        :param battery_voltage: The battery_voltage of this NodeResponse.  # noqa: E501
        :type: float
        """

        self._battery_voltage = battery_voltage

    @property
    def burst_success_rate(self):
        """Gets the burst_success_rate of this NodeResponse.  # noqa: E501


        :return: The burst_success_rate of this NodeResponse.  # noqa: E501
        :rtype: float
        """
        return self._burst_success_rate

    @burst_success_rate.setter
    def burst_success_rate(self, burst_success_rate):
        """Sets the burst_success_rate of this NodeResponse.


        :param burst_success_rate: The burst_success_rate of this NodeResponse.  # noqa: E501
        :type: float
        """

        self._burst_success_rate = burst_success_rate

    @property
    def is_online(self):
        """Gets the is_online of this NodeResponse.  # noqa: E501


        :return: The is_online of this NodeResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_online

    @is_online.setter
    def is_online(self, is_online):
        """Sets the is_online of this NodeResponse.


        :param is_online: The is_online of this NodeResponse.  # noqa: E501
        :type: bool
        """

        self._is_online = is_online

    @property
    def last_update_time(self):
        """Gets the last_update_time of this NodeResponse.  # noqa: E501


        :return: The last_update_time of this NodeResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_time

    @last_update_time.setter
    def last_update_time(self, last_update_time):
        """Sets the last_update_time of this NodeResponse.


        :param last_update_time: The last_update_time of this NodeResponse.  # noqa: E501
        :type: datetime
        """

        self._last_update_time = last_update_time

    @property
    def packet_success_rate(self):
        """Gets the packet_success_rate of this NodeResponse.  # noqa: E501


        :return: The packet_success_rate of this NodeResponse.  # noqa: E501
        :rtype: float
        """
        return self._packet_success_rate

    @packet_success_rate.setter
    def packet_success_rate(self, packet_success_rate):
        """Sets the packet_success_rate of this NodeResponse.


        :param packet_success_rate: The packet_success_rate of this NodeResponse.  # noqa: E501
        :type: float
        """

        self._packet_success_rate = packet_success_rate

    @property
    def temperature(self):
        """Gets the temperature of this NodeResponse.  # noqa: E501


        :return: The temperature of this NodeResponse.  # noqa: E501
        :rtype: float
        """
        return self._temperature

    @temperature.setter
    def temperature(self, temperature):
        """Sets the temperature of this NodeResponse.


        :param temperature: The temperature of this NodeResponse.  # noqa: E501
        :type: float
        """

        self._temperature = temperature

    @property
    def wireless_efficiency(self):
        """Gets the wireless_efficiency of this NodeResponse.  # noqa: E501


        :return: The wireless_efficiency of this NodeResponse.  # noqa: E501
        :rtype: float
        """
        return self._wireless_efficiency

    @wireless_efficiency.setter
    def wireless_efficiency(self, wireless_efficiency):
        """Sets the wireless_efficiency of this NodeResponse.


        :param wireless_efficiency: The wireless_efficiency of this NodeResponse.  # noqa: E501
        :type: float
        """

        self._wireless_efficiency = wireless_efficiency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NodeResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AssetClassificationAssignmentResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset': 'GroupChild',
        'asset_type': 'AssetTypeChild',
        'asset_category': 'AssetClassificationCategoryChild',
        'parameter_values': 'list[AssetClassificationParameterValueChild]'
    }

    attribute_map = {
        'asset': 'Asset',
        'asset_type': 'AssetType',
        'asset_category': 'AssetCategory',
        'parameter_values': 'ParameterValues'
    }

    def __init__(self, asset=None, asset_type=None, asset_category=None, parameter_values=None):  # noqa: E501
        """AssetClassificationAssignmentResponse - a model defined in Swagger"""  # noqa: E501
        self._asset = None
        self._asset_type = None
        self._asset_category = None
        self._parameter_values = None
        self.discriminator = None
        self.asset = asset
        if asset_type is not None:
            self.asset_type = asset_type
        if asset_category is not None:
            self.asset_category = asset_category
        self.parameter_values = parameter_values

    @property
    def asset(self):
        """Gets the asset of this AssetClassificationAssignmentResponse.  # noqa: E501


        :return: The asset of this AssetClassificationAssignmentResponse.  # noqa: E501
        :rtype: GroupChild
        """
        return self._asset

    @asset.setter
    def asset(self, asset):
        """Sets the asset of this AssetClassificationAssignmentResponse.


        :param asset: The asset of this AssetClassificationAssignmentResponse.  # noqa: E501
        :type: GroupChild
        """
        if asset is None:
            raise ValueError("Invalid value for `asset`, must not be `None`")  # noqa: E501

        self._asset = asset

    @property
    def asset_type(self):
        """Gets the asset_type of this AssetClassificationAssignmentResponse.  # noqa: E501


        :return: The asset_type of this AssetClassificationAssignmentResponse.  # noqa: E501
        :rtype: AssetTypeChild
        """
        return self._asset_type

    @asset_type.setter
    def asset_type(self, asset_type):
        """Sets the asset_type of this AssetClassificationAssignmentResponse.


        :param asset_type: The asset_type of this AssetClassificationAssignmentResponse.  # noqa: E501
        :type: AssetTypeChild
        """

        self._asset_type = asset_type

    @property
    def asset_category(self):
        """Gets the asset_category of this AssetClassificationAssignmentResponse.  # noqa: E501


        :return: The asset_category of this AssetClassificationAssignmentResponse.  # noqa: E501
        :rtype: AssetClassificationCategoryChild
        """
        return self._asset_category

    @asset_category.setter
    def asset_category(self, asset_category):
        """Sets the asset_category of this AssetClassificationAssignmentResponse.


        :param asset_category: The asset_category of this AssetClassificationAssignmentResponse.  # noqa: E501
        :type: AssetClassificationCategoryChild
        """

        self._asset_category = asset_category

    @property
    def parameter_values(self):
        """Gets the parameter_values of this AssetClassificationAssignmentResponse.  # noqa: E501

        A list of parameter values made of a code and value.  A code describes the value being assigned.   Code = \"piston.count\", Value = \"3\"  Will return an empty list when an asset has no parameter values assigned.  # noqa: E501

        :return: The parameter_values of this AssetClassificationAssignmentResponse.  # noqa: E501
        :rtype: list[AssetClassificationParameterValueChild]
        """
        return self._parameter_values

    @parameter_values.setter
    def parameter_values(self, parameter_values):
        """Sets the parameter_values of this AssetClassificationAssignmentResponse.

        A list of parameter values made of a code and value.  A code describes the value being assigned.   Code = \"piston.count\", Value = \"3\"  Will return an empty list when an asset has no parameter values assigned.  # noqa: E501

        :param parameter_values: The parameter_values of this AssetClassificationAssignmentResponse.  # noqa: E501
        :type: list[AssetClassificationParameterValueChild]
        """
        if parameter_values is None:
            raise ValueError("Invalid value for `parameter_values`, must not be `None`")  # noqa: E501

        self._parameter_values = parameter_values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AssetClassificationAssignmentResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetClassificationAssignmentResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class IndicatorStatisticsResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'system_sort_order': 'int',
        'indicator_type': 'MetricTypeCodes',
        'measure_of': 'SensorRoleTypeCodes',
        'display_units': 'str',
        'last_measurement': 'datetime',
        'average_value': 'float',
        'max_value': 'float',
        'time_in_alarm': 'float',
        'time_in_warning': 'float',
        'on_time': 'float',
        'hierarchy': 'list[IndicatorStatisticsHierarchyChild]',
        'start_date': 'datetime',
        'end_date': 'datetime'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'system_sort_order': 'SystemSortOrder',
        'indicator_type': 'IndicatorType',
        'measure_of': 'MeasureOf',
        'display_units': 'DisplayUnits',
        'last_measurement': 'LastMeasurement',
        'average_value': 'AverageValue',
        'max_value': 'MaxValue',
        'time_in_alarm': 'TimeInAlarm',
        'time_in_warning': 'TimeInWarning',
        'on_time': 'OnTime',
        'hierarchy': 'Hierarchy',
        'start_date': 'StartDate',
        'end_date': 'EndDate'
    }

    def __init__(self, id=None, name=None, system_sort_order=None, indicator_type=None, measure_of=None, display_units=None, last_measurement=None, average_value=None, max_value=None, time_in_alarm=None, time_in_warning=None, on_time=None, hierarchy=None, start_date=None, end_date=None):  # noqa: E501
        """IndicatorStatisticsResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._system_sort_order = None
        self._indicator_type = None
        self._measure_of = None
        self._display_units = None
        self._last_measurement = None
        self._average_value = None
        self._max_value = None
        self._time_in_alarm = None
        self._time_in_warning = None
        self._on_time = None
        self._hierarchy = None
        self._start_date = None
        self._end_date = None
        self.discriminator = None
        self.id = id
        self.name = name
        if system_sort_order is not None:
            self.system_sort_order = system_sort_order
        self.indicator_type = indicator_type
        if measure_of is not None:
            self.measure_of = measure_of
        if display_units is not None:
            self.display_units = display_units
        if last_measurement is not None:
            self.last_measurement = last_measurement
        if average_value is not None:
            self.average_value = average_value
        if max_value is not None:
            self.max_value = max_value
        if time_in_alarm is not None:
            self.time_in_alarm = time_in_alarm
        if time_in_warning is not None:
            self.time_in_warning = time_in_warning
        if on_time is not None:
            self.on_time = on_time
        if hierarchy is not None:
            self.hierarchy = hierarchy
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date

    @property
    def id(self):
        """Gets the id of this IndicatorStatisticsResponse.  # noqa: E501


        :return: The id of this IndicatorStatisticsResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IndicatorStatisticsResponse.


        :param id: The id of this IndicatorStatisticsResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this IndicatorStatisticsResponse.  # noqa: E501


        :return: The name of this IndicatorStatisticsResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IndicatorStatisticsResponse.


        :param name: The name of this IndicatorStatisticsResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def system_sort_order(self):
        """Gets the system_sort_order of this IndicatorStatisticsResponse.  # noqa: E501


        :return: The system_sort_order of this IndicatorStatisticsResponse.  # noqa: E501
        :rtype: int
        """
        return self._system_sort_order

    @system_sort_order.setter
    def system_sort_order(self, system_sort_order):
        """Sets the system_sort_order of this IndicatorStatisticsResponse.


        :param system_sort_order: The system_sort_order of this IndicatorStatisticsResponse.  # noqa: E501
        :type: int
        """

        self._system_sort_order = system_sort_order

    @property
    def indicator_type(self):
        """Gets the indicator_type of this IndicatorStatisticsResponse.  # noqa: E501


        :return: The indicator_type of this IndicatorStatisticsResponse.  # noqa: E501
        :rtype: MetricTypeCodes
        """
        return self._indicator_type

    @indicator_type.setter
    def indicator_type(self, indicator_type):
        """Sets the indicator_type of this IndicatorStatisticsResponse.


        :param indicator_type: The indicator_type of this IndicatorStatisticsResponse.  # noqa: E501
        :type: MetricTypeCodes
        """
        if indicator_type is None:
            raise ValueError("Invalid value for `indicator_type`, must not be `None`")  # noqa: E501

        self._indicator_type = indicator_type

    @property
    def measure_of(self):
        """Gets the measure_of of this IndicatorStatisticsResponse.  # noqa: E501


        :return: The measure_of of this IndicatorStatisticsResponse.  # noqa: E501
        :rtype: SensorRoleTypeCodes
        """
        return self._measure_of

    @measure_of.setter
    def measure_of(self, measure_of):
        """Sets the measure_of of this IndicatorStatisticsResponse.


        :param measure_of: The measure_of of this IndicatorStatisticsResponse.  # noqa: E501
        :type: SensorRoleTypeCodes
        """

        self._measure_of = measure_of

    @property
    def display_units(self):
        """Gets the display_units of this IndicatorStatisticsResponse.  # noqa: E501


        :return: The display_units of this IndicatorStatisticsResponse.  # noqa: E501
        :rtype: str
        """
        return self._display_units

    @display_units.setter
    def display_units(self, display_units):
        """Sets the display_units of this IndicatorStatisticsResponse.


        :param display_units: The display_units of this IndicatorStatisticsResponse.  # noqa: E501
        :type: str
        """

        self._display_units = display_units

    @property
    def last_measurement(self):
        """Gets the last_measurement of this IndicatorStatisticsResponse.  # noqa: E501


        :return: The last_measurement of this IndicatorStatisticsResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._last_measurement

    @last_measurement.setter
    def last_measurement(self, last_measurement):
        """Sets the last_measurement of this IndicatorStatisticsResponse.


        :param last_measurement: The last_measurement of this IndicatorStatisticsResponse.  # noqa: E501
        :type: datetime
        """

        self._last_measurement = last_measurement

    @property
    def average_value(self):
        """Gets the average_value of this IndicatorStatisticsResponse.  # noqa: E501


        :return: The average_value of this IndicatorStatisticsResponse.  # noqa: E501
        :rtype: float
        """
        return self._average_value

    @average_value.setter
    def average_value(self, average_value):
        """Sets the average_value of this IndicatorStatisticsResponse.


        :param average_value: The average_value of this IndicatorStatisticsResponse.  # noqa: E501
        :type: float
        """

        self._average_value = average_value

    @property
    def max_value(self):
        """Gets the max_value of this IndicatorStatisticsResponse.  # noqa: E501


        :return: The max_value of this IndicatorStatisticsResponse.  # noqa: E501
        :rtype: float
        """
        return self._max_value

    @max_value.setter
    def max_value(self, max_value):
        """Sets the max_value of this IndicatorStatisticsResponse.


        :param max_value: The max_value of this IndicatorStatisticsResponse.  # noqa: E501
        :type: float
        """

        self._max_value = max_value

    @property
    def time_in_alarm(self):
        """Gets the time_in_alarm of this IndicatorStatisticsResponse.  # noqa: E501


        :return: The time_in_alarm of this IndicatorStatisticsResponse.  # noqa: E501
        :rtype: float
        """
        return self._time_in_alarm

    @time_in_alarm.setter
    def time_in_alarm(self, time_in_alarm):
        """Sets the time_in_alarm of this IndicatorStatisticsResponse.


        :param time_in_alarm: The time_in_alarm of this IndicatorStatisticsResponse.  # noqa: E501
        :type: float
        """

        self._time_in_alarm = time_in_alarm

    @property
    def time_in_warning(self):
        """Gets the time_in_warning of this IndicatorStatisticsResponse.  # noqa: E501


        :return: The time_in_warning of this IndicatorStatisticsResponse.  # noqa: E501
        :rtype: float
        """
        return self._time_in_warning

    @time_in_warning.setter
    def time_in_warning(self, time_in_warning):
        """Sets the time_in_warning of this IndicatorStatisticsResponse.


        :param time_in_warning: The time_in_warning of this IndicatorStatisticsResponse.  # noqa: E501
        :type: float
        """

        self._time_in_warning = time_in_warning

    @property
    def on_time(self):
        """Gets the on_time of this IndicatorStatisticsResponse.  # noqa: E501


        :return: The on_time of this IndicatorStatisticsResponse.  # noqa: E501
        :rtype: float
        """
        return self._on_time

    @on_time.setter
    def on_time(self, on_time):
        """Sets the on_time of this IndicatorStatisticsResponse.


        :param on_time: The on_time of this IndicatorStatisticsResponse.  # noqa: E501
        :type: float
        """

        self._on_time = on_time

    @property
    def hierarchy(self):
        """Gets the hierarchy of this IndicatorStatisticsResponse.  # noqa: E501


        :return: The hierarchy of this IndicatorStatisticsResponse.  # noqa: E501
        :rtype: list[IndicatorStatisticsHierarchyChild]
        """
        return self._hierarchy

    @hierarchy.setter
    def hierarchy(self, hierarchy):
        """Sets the hierarchy of this IndicatorStatisticsResponse.


        :param hierarchy: The hierarchy of this IndicatorStatisticsResponse.  # noqa: E501
        :type: list[IndicatorStatisticsHierarchyChild]
        """

        self._hierarchy = hierarchy

    @property
    def start_date(self):
        """Gets the start_date of this IndicatorStatisticsResponse.  # noqa: E501


        :return: The start_date of this IndicatorStatisticsResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this IndicatorStatisticsResponse.


        :param start_date: The start_date of this IndicatorStatisticsResponse.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this IndicatorStatisticsResponse.  # noqa: E501


        :return: The end_date of this IndicatorStatisticsResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this IndicatorStatisticsResponse.


        :param end_date: The end_date of this IndicatorStatisticsResponse.  # noqa: E501
        :type: datetime
        """

        self._end_date = end_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IndicatorStatisticsResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IndicatorStatisticsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.installs_api import InstallsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestInstallsApi(unittest.TestCase):
    """InstallsApi unit test stubs"""

    def setUp(self):
        self.api = InstallsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_users_to_install(self):
        """Test case for add_users_to_install

        Adds one or more users to an install  # noqa: E501
        """
        pass

    def test_export_install_report(self):
        """Test case for export_install_report

        Triggers a Hangfire job that will email an install's status report to the user  # noqa: E501
        """
        pass

    def test_get_install(self):
        """Test case for get_install

        Gets a single Install  # noqa: E501
        """
        pass

    def test_get_installs(self):
        """Test case for get_installs

        Gets a list of installs for the current user  # noqa: E501
        """
        pass

    def test_get_node_install_status(self):
        """Test case for get_node_install_status

        Gets a list of nodes per install  # noqa: E501
        """
        pass

    def test_remove_users_from_install(self):
        """Test case for remove_users_from_install

        Removes one or more users from an install  # noqa: E501
        """
        pass

    def test_update_install(self):
        """Test case for update_install

        Updates properties related to an install  # noqa: E501
        """
        pass

    def test_update_node_install_status(self):
        """Test case for update_node_install_status

        Updates a node's status for the install  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class HardwareEventModelV3(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'hardware_type': 'str',
        'event_type': 'str',
        'time_entered': 'datetime',
        'time_notified': 'datetime',
        'time_exited': 'datetime',
        'time_acked': 'datetime',
        'created': 'datetime',
        'last_modified': 'datetime',
        'node': 'HardwareModelV3',
        'collector': 'HardwareModelV3',
        'repeater': 'HardwareModelV3'
    }

    attribute_map = {
        'id': 'Id',
        'hardware_type': 'HardwareType',
        'event_type': 'EventType',
        'time_entered': 'TimeEntered',
        'time_notified': 'TimeNotified',
        'time_exited': 'TimeExited',
        'time_acked': 'TimeAcked',
        'created': 'Created',
        'last_modified': 'LastModified',
        'node': 'Node',
        'collector': 'Collector',
        'repeater': 'Repeater'
    }

    def __init__(self, id=None, hardware_type=None, event_type=None, time_entered=None, time_notified=None, time_exited=None, time_acked=None, created=None, last_modified=None, node=None, collector=None, repeater=None):  # noqa: E501
        """HardwareEventModelV3 - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._hardware_type = None
        self._event_type = None
        self._time_entered = None
        self._time_notified = None
        self._time_exited = None
        self._time_acked = None
        self._created = None
        self._last_modified = None
        self._node = None
        self._collector = None
        self._repeater = None
        self.discriminator = None
        self.id = id
        if hardware_type is not None:
            self.hardware_type = hardware_type
        if event_type is not None:
            self.event_type = event_type
        if time_entered is not None:
            self.time_entered = time_entered
        if time_notified is not None:
            self.time_notified = time_notified
        if time_exited is not None:
            self.time_exited = time_exited
        if time_acked is not None:
            self.time_acked = time_acked
        if created is not None:
            self.created = created
        if last_modified is not None:
            self.last_modified = last_modified
        if node is not None:
            self.node = node
        if collector is not None:
            self.collector = collector
        if repeater is not None:
            self.repeater = repeater

    @property
    def id(self):
        """Gets the id of this HardwareEventModelV3.  # noqa: E501

        The Id of the hardware event  # noqa: E501

        :return: The id of this HardwareEventModelV3.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this HardwareEventModelV3.

        The Id of the hardware event  # noqa: E501

        :param id: The id of this HardwareEventModelV3.  # noqa: E501
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def hardware_type(self):
        """Gets the hardware_type of this HardwareEventModelV3.  # noqa: E501

        The type of hardware that caused the event  # noqa: E501

        :return: The hardware_type of this HardwareEventModelV3.  # noqa: E501
        :rtype: str
        """
        return self._hardware_type

    @hardware_type.setter
    def hardware_type(self, hardware_type):
        """Sets the hardware_type of this HardwareEventModelV3.

        The type of hardware that caused the event  # noqa: E501

        :param hardware_type: The hardware_type of this HardwareEventModelV3.  # noqa: E501
        :type: str
        """

        self._hardware_type = hardware_type

    @property
    def event_type(self):
        """Gets the event_type of this HardwareEventModelV3.  # noqa: E501

        The event type that happened  # noqa: E501

        :return: The event_type of this HardwareEventModelV3.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this HardwareEventModelV3.

        The event type that happened  # noqa: E501

        :param event_type: The event_type of this HardwareEventModelV3.  # noqa: E501
        :type: str
        """

        self._event_type = event_type

    @property
    def time_entered(self):
        """Gets the time_entered of this HardwareEventModelV3.  # noqa: E501

        Time hardware enter the event type  # noqa: E501

        :return: The time_entered of this HardwareEventModelV3.  # noqa: E501
        :rtype: datetime
        """
        return self._time_entered

    @time_entered.setter
    def time_entered(self, time_entered):
        """Sets the time_entered of this HardwareEventModelV3.

        Time hardware enter the event type  # noqa: E501

        :param time_entered: The time_entered of this HardwareEventModelV3.  # noqa: E501
        :type: datetime
        """

        self._time_entered = time_entered

    @property
    def time_notified(self):
        """Gets the time_notified of this HardwareEventModelV3.  # noqa: E501

        Time notifications where sent out  # noqa: E501

        :return: The time_notified of this HardwareEventModelV3.  # noqa: E501
        :rtype: datetime
        """
        return self._time_notified

    @time_notified.setter
    def time_notified(self, time_notified):
        """Sets the time_notified of this HardwareEventModelV3.

        Time notifications where sent out  # noqa: E501

        :param time_notified: The time_notified of this HardwareEventModelV3.  # noqa: E501
        :type: datetime
        """

        self._time_notified = time_notified

    @property
    def time_exited(self):
        """Gets the time_exited of this HardwareEventModelV3.  # noqa: E501

        The time the hardware exited the event  # noqa: E501

        :return: The time_exited of this HardwareEventModelV3.  # noqa: E501
        :rtype: datetime
        """
        return self._time_exited

    @time_exited.setter
    def time_exited(self, time_exited):
        """Sets the time_exited of this HardwareEventModelV3.

        The time the hardware exited the event  # noqa: E501

        :param time_exited: The time_exited of this HardwareEventModelV3.  # noqa: E501
        :type: datetime
        """

        self._time_exited = time_exited

    @property
    def time_acked(self):
        """Gets the time_acked of this HardwareEventModelV3.  # noqa: E501

        Time a user acknowledged the event  # noqa: E501

        :return: The time_acked of this HardwareEventModelV3.  # noqa: E501
        :rtype: datetime
        """
        return self._time_acked

    @time_acked.setter
    def time_acked(self, time_acked):
        """Sets the time_acked of this HardwareEventModelV3.

        Time a user acknowledged the event  # noqa: E501

        :param time_acked: The time_acked of this HardwareEventModelV3.  # noqa: E501
        :type: datetime
        """

        self._time_acked = time_acked

    @property
    def created(self):
        """Gets the created of this HardwareEventModelV3.  # noqa: E501

        Time the log entry was created  # noqa: E501

        :return: The created of this HardwareEventModelV3.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this HardwareEventModelV3.

        Time the log entry was created  # noqa: E501

        :param created: The created of this HardwareEventModelV3.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def last_modified(self):
        """Gets the last_modified of this HardwareEventModelV3.  # noqa: E501

        Last time the event entry was modified  # noqa: E501

        :return: The last_modified of this HardwareEventModelV3.  # noqa: E501
        :rtype: datetime
        """
        return self._last_modified

    @last_modified.setter
    def last_modified(self, last_modified):
        """Sets the last_modified of this HardwareEventModelV3.

        Last time the event entry was modified  # noqa: E501

        :param last_modified: The last_modified of this HardwareEventModelV3.  # noqa: E501
        :type: datetime
        """

        self._last_modified = last_modified

    @property
    def node(self):
        """Gets the node of this HardwareEventModelV3.  # noqa: E501


        :return: The node of this HardwareEventModelV3.  # noqa: E501
        :rtype: HardwareModelV3
        """
        return self._node

    @node.setter
    def node(self, node):
        """Sets the node of this HardwareEventModelV3.


        :param node: The node of this HardwareEventModelV3.  # noqa: E501
        :type: HardwareModelV3
        """

        self._node = node

    @property
    def collector(self):
        """Gets the collector of this HardwareEventModelV3.  # noqa: E501


        :return: The collector of this HardwareEventModelV3.  # noqa: E501
        :rtype: HardwareModelV3
        """
        return self._collector

    @collector.setter
    def collector(self, collector):
        """Sets the collector of this HardwareEventModelV3.


        :param collector: The collector of this HardwareEventModelV3.  # noqa: E501
        :type: HardwareModelV3
        """

        self._collector = collector

    @property
    def repeater(self):
        """Gets the repeater of this HardwareEventModelV3.  # noqa: E501


        :return: The repeater of this HardwareEventModelV3.  # noqa: E501
        :rtype: HardwareModelV3
        """
        return self._repeater

    @repeater.setter
    def repeater(self, repeater):
        """Sets the repeater of this HardwareEventModelV3.


        :param repeater: The repeater of this HardwareEventModelV3.  # noqa: E501
        :type: HardwareModelV3
        """

        self._repeater = repeater

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HardwareEventModelV3, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HardwareEventModelV3):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class IndicatorFilterUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'indicator_types': 'list[MetricTypeCodes]',
        'sort_order': 'int',
        'tag_ids': 'list[str]'
    }

    attribute_map = {
        'name': 'Name',
        'indicator_types': 'IndicatorTypes',
        'sort_order': 'SortOrder',
        'tag_ids': 'TagIds'
    }

    def __init__(self, name=None, indicator_types=None, sort_order=None, tag_ids=None):  # noqa: E501
        """IndicatorFilterUpdateRequest - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._indicator_types = None
        self._sort_order = None
        self._tag_ids = None
        self.discriminator = None
        self.name = name
        if indicator_types is not None:
            self.indicator_types = indicator_types
        if sort_order is not None:
            self.sort_order = sort_order
        if tag_ids is not None:
            self.tag_ids = tag_ids

    @property
    def name(self):
        """Gets the name of this IndicatorFilterUpdateRequest.  # noqa: E501


        :return: The name of this IndicatorFilterUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IndicatorFilterUpdateRequest.


        :param name: The name of this IndicatorFilterUpdateRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def indicator_types(self):
        """Gets the indicator_types of this IndicatorFilterUpdateRequest.  # noqa: E501


        :return: The indicator_types of this IndicatorFilterUpdateRequest.  # noqa: E501
        :rtype: list[MetricTypeCodes]
        """
        return self._indicator_types

    @indicator_types.setter
    def indicator_types(self, indicator_types):
        """Sets the indicator_types of this IndicatorFilterUpdateRequest.


        :param indicator_types: The indicator_types of this IndicatorFilterUpdateRequest.  # noqa: E501
        :type: list[MetricTypeCodes]
        """

        self._indicator_types = indicator_types

    @property
    def sort_order(self):
        """Gets the sort_order of this IndicatorFilterUpdateRequest.  # noqa: E501


        :return: The sort_order of this IndicatorFilterUpdateRequest.  # noqa: E501
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this IndicatorFilterUpdateRequest.


        :param sort_order: The sort_order of this IndicatorFilterUpdateRequest.  # noqa: E501
        :type: int
        """

        self._sort_order = sort_order

    @property
    def tag_ids(self):
        """Gets the tag_ids of this IndicatorFilterUpdateRequest.  # noqa: E501


        :return: The tag_ids of this IndicatorFilterUpdateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._tag_ids

    @tag_ids.setter
    def tag_ids(self, tag_ids):
        """Sets the tag_ids of this IndicatorFilterUpdateRequest.


        :param tag_ids: The tag_ids of this IndicatorFilterUpdateRequest.  # noqa: E501
        :type: list[str]
        """

        self._tag_ids = tag_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IndicatorFilterUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IndicatorFilterUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SessionIndicatorTypeChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'indicator_type': 'MetricTypeCodes',
        'numeric_value': 'int'
    }

    attribute_map = {
        'indicator_type': 'IndicatorType',
        'numeric_value': 'NumericValue'
    }

    def __init__(self, indicator_type=None, numeric_value=None):  # noqa: E501
        """SessionIndicatorTypeChild - a model defined in Swagger"""  # noqa: E501
        self._indicator_type = None
        self._numeric_value = None
        self.discriminator = None
        self.indicator_type = indicator_type
        self.numeric_value = numeric_value

    @property
    def indicator_type(self):
        """Gets the indicator_type of this SessionIndicatorTypeChild.  # noqa: E501


        :return: The indicator_type of this SessionIndicatorTypeChild.  # noqa: E501
        :rtype: MetricTypeCodes
        """
        return self._indicator_type

    @indicator_type.setter
    def indicator_type(self, indicator_type):
        """Sets the indicator_type of this SessionIndicatorTypeChild.


        :param indicator_type: The indicator_type of this SessionIndicatorTypeChild.  # noqa: E501
        :type: MetricTypeCodes
        """
        if indicator_type is None:
            raise ValueError("Invalid value for `indicator_type`, must not be `None`")  # noqa: E501

        self._indicator_type = indicator_type

    @property
    def numeric_value(self):
        """Gets the numeric_value of this SessionIndicatorTypeChild.  # noqa: E501


        :return: The numeric_value of this SessionIndicatorTypeChild.  # noqa: E501
        :rtype: int
        """
        return self._numeric_value

    @numeric_value.setter
    def numeric_value(self, numeric_value):
        """Sets the numeric_value of this SessionIndicatorTypeChild.


        :param numeric_value: The numeric_value of this SessionIndicatorTypeChild.  # noqa: E501
        :type: int
        """
        if numeric_value is None:
            raise ValueError("Invalid value for `numeric_value`, must not be `None`")  # noqa: E501

        self._numeric_value = numeric_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SessionIndicatorTypeChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SessionIndicatorTypeChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.repeaters_api import RepeatersApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestRepeatersApi(unittest.TestCase):
    """RepeatersApi unit test stubs"""

    def setUp(self):
        self.api = RepeatersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_export_repeaters(self):
        """Test case for export_repeaters

        Requests a Repeater export.  # noqa: E501
        """
        pass

    def test_get_repeater_overview(self):
        """Test case for get_repeater_overview

        Gets a single repeater overview  # noqa: E501
        """
        pass

    def test_get_repeaters_overview(self):
        """Test case for get_repeaters_overview

        Gets repeaters  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TicketUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'status_id': 'str',
        'board_id': 'str',
        'is_archived': 'bool',
        'asset_ids': 'list[str]'
    }

    attribute_map = {
        'name': 'Name',
        'description': 'Description',
        'status_id': 'StatusId',
        'board_id': 'BoardId',
        'is_archived': 'IsArchived',
        'asset_ids': 'AssetIds'
    }

    def __init__(self, name=None, description=None, status_id=None, board_id=None, is_archived=None, asset_ids=None):  # noqa: E501
        """TicketUpdateRequest - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._description = None
        self._status_id = None
        self._board_id = None
        self._is_archived = None
        self._asset_ids = None
        self.discriminator = None
        self.name = name
        if description is not None:
            self.description = description
        self.status_id = status_id
        self.board_id = board_id
        self.is_archived = is_archived
        if asset_ids is not None:
            self.asset_ids = asset_ids

    @property
    def name(self):
        """Gets the name of this TicketUpdateRequest.  # noqa: E501

        Ticket name  # noqa: E501

        :return: The name of this TicketUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TicketUpdateRequest.

        Ticket name  # noqa: E501

        :param name: The name of this TicketUpdateRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this TicketUpdateRequest.  # noqa: E501

        Ticket description  # noqa: E501

        :return: The description of this TicketUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TicketUpdateRequest.

        Ticket description  # noqa: E501

        :param description: The description of this TicketUpdateRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def status_id(self):
        """Gets the status_id of this TicketUpdateRequest.  # noqa: E501

        The id of the status of the ticket  # noqa: E501

        :return: The status_id of this TicketUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._status_id

    @status_id.setter
    def status_id(self, status_id):
        """Sets the status_id of this TicketUpdateRequest.

        The id of the status of the ticket  # noqa: E501

        :param status_id: The status_id of this TicketUpdateRequest.  # noqa: E501
        :type: str
        """
        if status_id is None:
            raise ValueError("Invalid value for `status_id`, must not be `None`")  # noqa: E501

        self._status_id = status_id

    @property
    def board_id(self):
        """Gets the board_id of this TicketUpdateRequest.  # noqa: E501

        Id of the board the ticket is in  # noqa: E501

        :return: The board_id of this TicketUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._board_id

    @board_id.setter
    def board_id(self, board_id):
        """Sets the board_id of this TicketUpdateRequest.

        Id of the board the ticket is in  # noqa: E501

        :param board_id: The board_id of this TicketUpdateRequest.  # noqa: E501
        :type: str
        """
        if board_id is None:
            raise ValueError("Invalid value for `board_id`, must not be `None`")  # noqa: E501

        self._board_id = board_id

    @property
    def is_archived(self):
        """Gets the is_archived of this TicketUpdateRequest.  # noqa: E501

        If the ticket is archived or not  # noqa: E501

        :return: The is_archived of this TicketUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_archived

    @is_archived.setter
    def is_archived(self, is_archived):
        """Sets the is_archived of this TicketUpdateRequest.

        If the ticket is archived or not  # noqa: E501

        :param is_archived: The is_archived of this TicketUpdateRequest.  # noqa: E501
        :type: bool
        """
        if is_archived is None:
            raise ValueError("Invalid value for `is_archived`, must not be `None`")  # noqa: E501

        self._is_archived = is_archived

    @property
    def asset_ids(self):
        """Gets the asset_ids of this TicketUpdateRequest.  # noqa: E501

        Ids of assets associated with the ticket  # noqa: E501

        :return: The asset_ids of this TicketUpdateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._asset_ids

    @asset_ids.setter
    def asset_ids(self, asset_ids):
        """Sets the asset_ids of this TicketUpdateRequest.

        Ids of assets associated with the ticket  # noqa: E501

        :param asset_ids: The asset_ids of this TicketUpdateRequest.  # noqa: E501
        :type: list[str]
        """

        self._asset_ids = asset_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TicketUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TicketUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ActivityEventCategoryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'code': 'str',
        'name': 'str',
        'description': 'str',
        'activity_line_enabled': 'bool',
        'category_flag': 'ActivityEventCategoryFlag',
        'asset_card_enabled': 'bool',
        'owner': 'ActivityEventCategoryOwnerChild',
        'internal': 'bool',
        'subcategories': 'list[ActivityEventSubcategoryChild]',
        'fields': 'list[ActivityEventFieldChild]'
    }

    attribute_map = {
        'id': 'Id',
        'code': 'Code',
        'name': 'Name',
        'description': 'Description',
        'activity_line_enabled': 'ActivityLineEnabled',
        'category_flag': 'CategoryFlag',
        'asset_card_enabled': 'AssetCardEnabled',
        'owner': 'Owner',
        'internal': 'Internal',
        'subcategories': 'Subcategories',
        'fields': 'Fields'
    }

    def __init__(self, id=None, code=None, name=None, description=None, activity_line_enabled=None, category_flag=None, asset_card_enabled=None, owner=None, internal=None, subcategories=None, fields=None):  # noqa: E501
        """ActivityEventCategoryResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._code = None
        self._name = None
        self._description = None
        self._activity_line_enabled = None
        self._category_flag = None
        self._asset_card_enabled = None
        self._owner = None
        self._internal = None
        self._subcategories = None
        self._fields = None
        self.discriminator = None
        self.id = id
        self.code = code
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if activity_line_enabled is not None:
            self.activity_line_enabled = activity_line_enabled
        if category_flag is not None:
            self.category_flag = category_flag
        if asset_card_enabled is not None:
            self.asset_card_enabled = asset_card_enabled
        if owner is not None:
            self.owner = owner
        if internal is not None:
            self.internal = internal
        if subcategories is not None:
            self.subcategories = subcategories
        if fields is not None:
            self.fields = fields

    @property
    def id(self):
        """Gets the id of this ActivityEventCategoryResponse.  # noqa: E501


        :return: The id of this ActivityEventCategoryResponse.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ActivityEventCategoryResponse.


        :param id: The id of this ActivityEventCategoryResponse.  # noqa: E501
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def code(self):
        """Gets the code of this ActivityEventCategoryResponse.  # noqa: E501


        :return: The code of this ActivityEventCategoryResponse.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this ActivityEventCategoryResponse.


        :param code: The code of this ActivityEventCategoryResponse.  # noqa: E501
        :type: str
        """
        if code is None:
            raise ValueError("Invalid value for `code`, must not be `None`")  # noqa: E501

        self._code = code

    @property
    def name(self):
        """Gets the name of this ActivityEventCategoryResponse.  # noqa: E501


        :return: The name of this ActivityEventCategoryResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ActivityEventCategoryResponse.


        :param name: The name of this ActivityEventCategoryResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this ActivityEventCategoryResponse.  # noqa: E501


        :return: The description of this ActivityEventCategoryResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ActivityEventCategoryResponse.


        :param description: The description of this ActivityEventCategoryResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def activity_line_enabled(self):
        """Gets the activity_line_enabled of this ActivityEventCategoryResponse.  # noqa: E501


        :return: The activity_line_enabled of this ActivityEventCategoryResponse.  # noqa: E501
        :rtype: bool
        """
        return self._activity_line_enabled

    @activity_line_enabled.setter
    def activity_line_enabled(self, activity_line_enabled):
        """Sets the activity_line_enabled of this ActivityEventCategoryResponse.


        :param activity_line_enabled: The activity_line_enabled of this ActivityEventCategoryResponse.  # noqa: E501
        :type: bool
        """

        self._activity_line_enabled = activity_line_enabled

    @property
    def category_flag(self):
        """Gets the category_flag of this ActivityEventCategoryResponse.  # noqa: E501


        :return: The category_flag of this ActivityEventCategoryResponse.  # noqa: E501
        :rtype: ActivityEventCategoryFlag
        """
        return self._category_flag

    @category_flag.setter
    def category_flag(self, category_flag):
        """Sets the category_flag of this ActivityEventCategoryResponse.


        :param category_flag: The category_flag of this ActivityEventCategoryResponse.  # noqa: E501
        :type: ActivityEventCategoryFlag
        """

        self._category_flag = category_flag

    @property
    def asset_card_enabled(self):
        """Gets the asset_card_enabled of this ActivityEventCategoryResponse.  # noqa: E501


        :return: The asset_card_enabled of this ActivityEventCategoryResponse.  # noqa: E501
        :rtype: bool
        """
        return self._asset_card_enabled

    @asset_card_enabled.setter
    def asset_card_enabled(self, asset_card_enabled):
        """Sets the asset_card_enabled of this ActivityEventCategoryResponse.


        :param asset_card_enabled: The asset_card_enabled of this ActivityEventCategoryResponse.  # noqa: E501
        :type: bool
        """

        self._asset_card_enabled = asset_card_enabled

    @property
    def owner(self):
        """Gets the owner of this ActivityEventCategoryResponse.  # noqa: E501


        :return: The owner of this ActivityEventCategoryResponse.  # noqa: E501
        :rtype: ActivityEventCategoryOwnerChild
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this ActivityEventCategoryResponse.


        :param owner: The owner of this ActivityEventCategoryResponse.  # noqa: E501
        :type: ActivityEventCategoryOwnerChild
        """

        self._owner = owner

    @property
    def internal(self):
        """Gets the internal of this ActivityEventCategoryResponse.  # noqa: E501


        :return: The internal of this ActivityEventCategoryResponse.  # noqa: E501
        :rtype: bool
        """
        return self._internal

    @internal.setter
    def internal(self, internal):
        """Sets the internal of this ActivityEventCategoryResponse.


        :param internal: The internal of this ActivityEventCategoryResponse.  # noqa: E501
        :type: bool
        """

        self._internal = internal

    @property
    def subcategories(self):
        """Gets the subcategories of this ActivityEventCategoryResponse.  # noqa: E501


        :return: The subcategories of this ActivityEventCategoryResponse.  # noqa: E501
        :rtype: list[ActivityEventSubcategoryChild]
        """
        return self._subcategories

    @subcategories.setter
    def subcategories(self, subcategories):
        """Sets the subcategories of this ActivityEventCategoryResponse.


        :param subcategories: The subcategories of this ActivityEventCategoryResponse.  # noqa: E501
        :type: list[ActivityEventSubcategoryChild]
        """

        self._subcategories = subcategories

    @property
    def fields(self):
        """Gets the fields of this ActivityEventCategoryResponse.  # noqa: E501


        :return: The fields of this ActivityEventCategoryResponse.  # noqa: E501
        :rtype: list[ActivityEventFieldChild]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this ActivityEventCategoryResponse.


        :param fields: The fields of this ActivityEventCategoryResponse.  # noqa: E501
        :type: list[ActivityEventFieldChild]
        """

        self._fields = fields

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivityEventCategoryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityEventCategoryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class LayoutChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'layout_row': 'int',
        'layout_column': 'int',
        'layout_height': 'int',
        'layout_width': 'int'
    }

    attribute_map = {
        'layout_row': 'LayoutRow',
        'layout_column': 'LayoutColumn',
        'layout_height': 'LayoutHeight',
        'layout_width': 'LayoutWidth'
    }

    def __init__(self, layout_row=None, layout_column=None, layout_height=None, layout_width=None):  # noqa: E501
        """LayoutChild - a model defined in Swagger"""  # noqa: E501
        self._layout_row = None
        self._layout_column = None
        self._layout_height = None
        self._layout_width = None
        self.discriminator = None
        self.layout_row = layout_row
        self.layout_column = layout_column
        self.layout_height = layout_height
        self.layout_width = layout_width

    @property
    def layout_row(self):
        """Gets the layout_row of this LayoutChild.  # noqa: E501


        :return: The layout_row of this LayoutChild.  # noqa: E501
        :rtype: int
        """
        return self._layout_row

    @layout_row.setter
    def layout_row(self, layout_row):
        """Sets the layout_row of this LayoutChild.


        :param layout_row: The layout_row of this LayoutChild.  # noqa: E501
        :type: int
        """
        if layout_row is None:
            raise ValueError("Invalid value for `layout_row`, must not be `None`")  # noqa: E501

        self._layout_row = layout_row

    @property
    def layout_column(self):
        """Gets the layout_column of this LayoutChild.  # noqa: E501


        :return: The layout_column of this LayoutChild.  # noqa: E501
        :rtype: int
        """
        return self._layout_column

    @layout_column.setter
    def layout_column(self, layout_column):
        """Sets the layout_column of this LayoutChild.


        :param layout_column: The layout_column of this LayoutChild.  # noqa: E501
        :type: int
        """
        if layout_column is None:
            raise ValueError("Invalid value for `layout_column`, must not be `None`")  # noqa: E501

        self._layout_column = layout_column

    @property
    def layout_height(self):
        """Gets the layout_height of this LayoutChild.  # noqa: E501


        :return: The layout_height of this LayoutChild.  # noqa: E501
        :rtype: int
        """
        return self._layout_height

    @layout_height.setter
    def layout_height(self, layout_height):
        """Sets the layout_height of this LayoutChild.


        :param layout_height: The layout_height of this LayoutChild.  # noqa: E501
        :type: int
        """
        if layout_height is None:
            raise ValueError("Invalid value for `layout_height`, must not be `None`")  # noqa: E501

        self._layout_height = layout_height

    @property
    def layout_width(self):
        """Gets the layout_width of this LayoutChild.  # noqa: E501


        :return: The layout_width of this LayoutChild.  # noqa: E501
        :rtype: int
        """
        return self._layout_width

    @layout_width.setter
    def layout_width(self, layout_width):
        """Sets the layout_width of this LayoutChild.


        :param layout_width: The layout_width of this LayoutChild.  # noqa: E501
        :type: int
        """
        if layout_width is None:
            raise ValueError("Invalid value for `layout_width`, must not be `None`")  # noqa: E501

        self._layout_width = layout_width

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LayoutChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LayoutChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
